@@ -18,7 +18,7 @@ namespace apg {
         public:
         GpuSearcher(int dev, int unicount, std::string symmetry);
         ~GpuSearcher();
-        std::vector<uint64_t> pump(std::string seed, uint64_t epoch);
+        void pump(std::string seed, uint64_t epoch, std::vector<uint64_t> &vec);
 
     };
 
