@@ -108,15 +108,16 @@ namespace apg {
             }
         }
 
-        void gc_traverse(uint32_t mindepth, bool destructive) {
+        template<bool destructive>
+        void gc_traverse(uint32_t mindepth) {
             /*
             * Run gc_traverse(false) to zero all gcflags;
             * Run gc_traverse(true) to delete all items with zero gcflags.
             */
             for (unsigned int i = 0; i < nonleaves.size(); i++) {
-                if (i + 1 >= mindepth) { nonleaves[i]->gc_traverse(destructive); }
+                if (i + 1 >= mindepth) { nonleaves[i]->template gc_traverse<2 * destructive + 1>(); }
             }
-            if (mindepth == 0) { leaves.gc_traverse(destructive); }
+            if (mindepth == 0) { leaves.template gc_traverse<2 * destructive + 1>(); }
         }
 
         // Recursively mark node to rescue it from garbage-collection:
@@ -160,7 +161,7 @@ namespace apg {
                 std::cerr << " -- emptying tree..." << std::endl;
             }
 
-            gc_traverse(mindepth, false);
+            gc_traverse<false>(mindepth);
 
             if (origbytes > 1000000000) {
                 std::cerr << " -- marking important nodes..." << std::endl;
@@ -177,7 +178,7 @@ namespace apg {
                 std::cerr << " -- removing surplus nodes..." << std::endl;
             }
 
-            gc_traverse(mindepth, true);
+            gc_traverse<true>(mindepth);
 
             if (origbytes > 1000000000) {
                 std::cerr << " -- completed." << std::endl;
