@@ -341,6 +341,14 @@ namespace apg {
             return this->popcount(modprime, -1);
         }
 
+        basepattern<I> matmul_mor(const basepattern<I> &other) {
+            return basepattern<I>(lab, lab->matmul_universe(hnode, coerce(other), false), rulestring);
+        }
+
+        basepattern<I> matmul_mxor(const basepattern<I> &other) {
+            return basepattern<I>(lab, lab->matmul_universe(hnode, coerce(other), true), rulestring);
+        }
+
         // Pattern matching:
 
         basepattern<I> convolve(const basepattern<I> &other) {
@@ -586,7 +594,7 @@ namespace apg {
             return phase_wechsler(maxarea, rule_symmetries());
         }
 
-        std::string apgcode(int maxarea, int maxlength) {
+        std::string apgcode(int maxarea, uint64_t maxlength) {
             /*
             * Returns the apgcode of a still-life, oscillator or spaceship:
             */
