@@ -135,6 +135,9 @@ class Pattern(object):
     def __imul__(self, other):
         return self._boolean_mutable(other, 4)
 
+    def __imatmul__(self, other):
+        return self._boolean_mutable(other, 7)
+
     def __and__(self, other):
         return self._boolean_immutable(other, 0)
 
@@ -153,6 +156,9 @@ class Pattern(object):
     def __mul__(self, other):
         return self._boolean_immutable(other, 4)
 
+    def __matmul__(self, other):
+        return self._boolean_immutable(other, 7)
+
     def __lshift__(self, other):
         return self._bitshift(other)
 
